Learn R Programming

meetupr (version 0.3.1)

meetupr_auth: Authenticate and return the current user

Description

Attempts to retrieve information about the currently authenticated user. On success a message is emitted and the user object is returned. On failure a message is shown and NULL is returned.

Usage

meetupr_auth(client_name = get_client_name())

Value

A user list (invisibly) or NULL on failure

Arguments

client_name

OAuth client name