Learn R Programming

meetupr (version 0.3.1)

meetupr_schema: Introspect the Meetup GraphQL API schema

Description

This function performs an introspection query on the Meetup GraphQL API to retrieve the full schema details, including available query types, mutation types, and type definitions.

Usage

meetupr_schema(asis = FALSE)

Value

If asis is FALSE (default), the parsed schema object with nested lists containing query types, mutation types, and type definitions. If asis is TRUE, a JSON string representation of the schema.

Arguments

asis

Logical; if TRUE, returns the raw response from the API as JSON. If FALSE (default), returns the parsed schema object.

Examples

Run this code
# \dontshow{
vcr::insert_example_cassette("meetupr_schema", package = "meetupr")
meetupr:::mock_if_no_auth()
# }
# Get the full schema
schema <- meetupr_schema()

# Explore what's available
names(schema)

# Get as JSON for external tools
schema_json <- meetupr_schema(asis = TRUE)
# \dontshow{
vcr::eject_cassette()
# }

Run the code above in your browser using DataLab