Learn R Programming

meetupr (version 0.3.1)

meetupr_schema_search: Search for types in the Meetup GraphQL API schema

Description

This function searches across all types in the schema by name or description. Useful for discovering what data structures are available (e.g., Event, Group, Venue, Member).

Usage

meetupr_schema_search(pattern, schema = meetupr_schema())

Value

A tibble with details about matching types:

type_name

Name of the type

kind

GraphQL kind (OBJECT, ENUM, INTERFACE, etc.)

description

Human-readable description

field_count

Number of fields in the type

Arguments

pattern

A string pattern to search for in type names and descriptions. The search is case-insensitive.

schema

The schema object obtained from meetupr_schema().

Examples

Run this code
if (FALSE) {
# Find all event-related types
meetupr_schema_search("event")

# Find location-related types
meetupr_schema_search("location")
}

Run the code above in your browser using DataLab