Learn R Programming

meetupr (version 0.3.1)

find_topics: Find topics on Meetup

Description

Search for topics on Meetup using a query string. This function allows you to find topics that match your search criteria.

Usage

find_topics(
  query,
  max_results = 200,
  handle_multiples = "list",
  extra_graphql = NULL,
  asis = FALSE,
  ...
)

Value

A data frame of topics matching the search query.

Arguments

query

A string query to search for topics.

max_results

Maximum number of results to return. If set to NULL, will return all available results (may take a long time).

handle_multiples

Character. How to handle multiple matches. One of "list" or "first", or "error". If "list", return a list-column with all matches. If "first", return only the first match.

extra_graphql

A graphql object. Extra objects to return

asis

Return the raw API response as-is without processing

...

Used for parameter expansion, must be empty.

Examples

Run this code
# \dontshow{
vcr::insert_example_cassette("find_topics", package = "meetupr")
meetupr:::mock_if_no_auth()
# }
find_topics("R", max_results = 10)
find_topics("Data Science", max_results = 5)
# \dontshow{
vcr::eject_cassette()
# }

Run the code above in your browser using DataLab