Learn R Programming

meetupr (version 0.3.1)

get_group_events: Get the events from a meetup group

Description

Get the events from a meetup group

Usage

get_group_events(
  urlname,
  status = NULL,
  date_before = NULL,
  date_after = NULL,
  max_results = NULL,
  handle_multiples = "list",
  extra_graphql = NULL,
  asis = FALSE,
  ...
)

Value

A tibble with the events for the specified group

Arguments

urlname

Character. The name of the group as indicated in the https://www.meetup.com/ url.

status

Character vector of event statuses to retrieve.

date_before

Datetime string in "YYYY-MM-DDTHH:MM:SSZ" (ISO8601) format. Events occurring before this date/time will be returned.

date_after

Datetime string in "YYYY-MM-DDTHH:MM:SSZ" (ISO8601) format. Events occurring after this date/time will be returned.

max_results

Maximum number of results to return. If set to NULL, will return all available results (may take a long time).

handle_multiples

Character. How to handle multiple matches. One of "list" or "first", or "error". If "list", return a list-column with all matches. If "first", return only the first match.

extra_graphql

A graphql object. Extra objects to return

asis

Return the raw API response as-is without processing

...

Should be empty. Used for parameter expansion

Examples

Run this code
# \dontshow{
vcr::insert_example_cassette("get_group_events", package = "meetupr")
meetupr:::mock_if_no_auth()
# }
get_group_events("rladies-lagos", "past")
get_group_events(
  "rladies-lagos",
  status = "past",
  date_before = "2023-01-01T12:00:00Z"
)
# \dontshow{
vcr::eject_cassette()
# }

Run the code above in your browser using DataLab